MinervaManager class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

becomeActive() Future<void>
단말앱이 활성 상태가 됨을 단말 라이브러리에게 알린다.
clearMsgListener() Future<void>
앱 서버에서 등록한 메시지 리스너를 해제한다.
clearRegisterResultListener() Future<void>
단말앱 등록 결과 리스너를 해제한다.
enableNotificationTracking({required Map<String, dynamic> data, String? appGroup}) Future<void>
해당 단말 푸시 알림의 수신 여부 트래킹 및 실시간 모니터링을 활성화한다.
enterBackground() Future<void>
단말앱이 백그라운드 상태가 됨을 단말 라이브러리에게 알린다.
isDeviceAppRegister({required String serviceId, required String deviceRegId}) Future<bool>
단말앱이 등록되어 있는지 확인한다.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerDevice({required String gateHost, required String serviceId, String? deviceRegName}) Future<void>
단말앱을 등록한다.
sendP2PMsg({required String data, required List<String> destDevices, bool supportMsgQ = true, String? notiTitle, String? notiBody}) Future<String?>
P2P 메시지를 발신한다.
sendUpstreamMsg({required String data, required String serverRegId}) Future<String?>
업스트림 메시지를 발신한다.
setAppGroup(String appGroup) Future<void>
설정한 앱 그룹을 라이브러리에게 알린다.
setDeviceToken(String deviceToken) Future<void>
푸시 알림용 단말 토큰을 설정한다.
setMsgListener(MessageListener listener) Future<void>
다운스트림 메시지 발신 결과와 업스트림 메시지 수신을 처리할 리스너를 등록한다.
setRegisterResultListener(DeviceRegisterResultListener listener) Future<void>
단말앱 등록 결과를 처리할 리스너를 등록한다.
toString() String
A string representation of this object.
inherited
unregisterDevice({required String serviceId}) Future<void>
단말앱을 등록 해제한다.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getInstance() MinervaManager